==> 4.6.1.tar.gz: terraform-provider-decort/internal/service/cloudapi/kvmvm/utility_data_source_compute.go <==
/*
Copyright (c) 2019-2022 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package kvmvm

import (
	"context"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudapi/compute"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
)

func utilityDataComputeCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (compute.RecordCompute, error) {
	c := m.(*controller.ControllerCfg)
	req := compute.GetRequest{
		ComputeID: uint64(d.Get("compute_id").(int)),
	}

	computeRecord, err := c.CloudAPI().Compute().Get(ctx, req)
	if err != nil {
		return compute.RecordCompute{}, err
	}

	return *computeRecord, nil
}

==> 4.9.0.tar.gz: terraform-provider-decort/internal/service/cloudapi/kvmvm/utility_data_source_compute.go <==
/*
Copyright (c) 2019-2022 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/*
Terraform DECORT provider - manage resources provided by DECORT (Digital Energy Cloud
Orchestration Technology) with Terraform by Hashicorp.

Source code: https://repository.basistech.ru/BASIS/terraform-provider-decort

Please see README.md to learn where to place source code so that it
builds seamlessly.

Documentation: https://repository.basistech.ru/BASIS/terraform-provider-decort/wiki
*/

package kvmvm

import (
	"context"
	"strconv"

	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/decort-golang-sdk/pkg/cloudapi/compute"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/controller"
)

func utilityDataComputeCheckPresence(ctx context.Context, d *schema.ResourceData, m interface{}) (compute.RecordCompute, error) {
	c := m.(*controller.ControllerCfg)
	req := compute.GetRequest{}
	if d.Id() != "" {
		computeId, _ := strconv.ParseUint(d.Id(), 10, 64)
		req.ComputeID = computeId
	} else {
		req.ComputeID = uint64(d.Get("compute_id").(int))
	}

	computeRecord, err := c.CloudAPI().Compute().Get(ctx, req)
	if err != nil {
		return compute.RecordCompute{}, err
	}

	return *computeRecord, nil
}

func utilityComputePCIDevicesList(ctx context.Context, d *schema.ResourceData, m interface{}) (*compute.ListPCIDevices, error) {
	c := m.(*controller.ControllerCfg)
	req := compute.ListPCIDeviceRequest{}

	if d.Id() != "" {
		computeId, _ := strconv.ParseUint(d.Id(), 10, 64)
		req.ComputeID = computeId
	} else {
		req.ComputeID = uint64(d.Get("compute_id").(int))
	}

	res, err := c.CloudAPI().Compute().ListPCIDevice(ctx, req)
	if err != nil {
		return nil, err
	}

	return res, nil
}
